# 0 - Script information ----

# Project: Trend analysis guidance ECDC
# Script name: Data preparation population data.r
# Date created: March 2021
# Script purpose: This r script prepares the population data: It takes what is relevant for the trend analysis guidance document and examples. First we create a dataset that contains the names of the countries, and then we use that to take the population data by year from only those countries we need.

#Script version: v1 - Original working version
#Add here any major changes to the r script


# 1 - Remember to set working directory ---------------------------------------

#To find out what is your current working directory
#getwd()

#If you are using an Rproject file, the working directory is already set up to the location of the Rproj file.

#Set working directory via Rstudio menu
#Session -> Set Working Directory -> "To Source File Location" (if r script already saved in the right folder)
#Session -> Set Working Directory -> "Choose Directory" (if you want to select the appropriate folder)
#Set working directory by adding code
#setwd("C:/data/...)


# 2 - Load packages -------------------------------------------------------

library(magrittr)
library(dplyr)


# 3- Opening population data file --------------------------------------------

#Get the excel spreadsheet sheet names
sheets <- readxl::excel_sheets("./0_source_data/20210212_Population_DataOutput.xlsx") 

#Preparing the list of countries and whether they are EU or EEA or not
CountryNames <- readxl::read_excel("./0_source_data/20210212_Population_DataOutput.xlsx",
                                   sheet = "ref.Country")

CountryNames <- CountryNames %>% 
  filter(isEU == TRUE | isEEA == TRUE) %>%
  select(CountryCode, CountryName)

#Open population data by year and keep only relevant countries

EUEEApopulation <- readxl::read_excel("./0_source_data/20210212_Population_DataOutput.xlsx",
                                      sheet = "ByYear") %>%
  right_join(CountryNames, by = "CountryCode") %>%
  select(Country, CountryCode, ReportYear, Population)


# 4 - Save data -----------------------------------------------------------

saveRDS(EUEEApopulation, file = "./0_source_data/EUEEApopulation.rds")


